<script setup>
import { ref, reactive } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postForm } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import { formatMessage } from '@/utils/localeUtils.js';
import useTableSearch from '@/utils/tableUtils.jsx';
import MatQueryView from '@/components/mat/matQuery/index.vue'

const router = useRouter();

const TABLE_KEY = 'table-locDetl';
const matQueryChild = ref(null)
const sourceLocNo = ref(null)
const targetLocNo = ref(null)

let tableData = ref([]);
getColumns();

const {
    getColumnSearchProps,
    handleResizeColumn,
} = useTableSearch();

const state = reactive({
    selectedRowKeys: [],
    loading: false,
    columns: [],
});
const onSelectChange = selectedRowKeys => {
    // console.log('selectedRowKeys changed: ', selectedRowKeys);
    state.selectedRowKeys = selectedRowKeys;
};

state.columns = [
    {
        title: formatMessage('db.man_loc_detl.loc_no', '库位号'),
        dataIndex: 'locNo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('locNo'),
    },
    {
        title: formatMessage('db.man_loc_detl.matnr', '商品编号'),
        dataIndex: 'matnr',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('matnr'),
    },
    {
        title: formatMessage('db.man_loc_detl.batch', '批号'),
        dataIndex: 'batch',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('batch'),
    },
    {
        title: formatMessage('db.man_loc_detl.anfme', '库存数量'),
        dataIndex: 'anfme',
        width: 140,
        ellipsis: true,
    },
];

let columnsOther = [
    // {
    //     title: formatMessage('db.man_loc_detl.loc_id', '库位'),
    //     dataIndex: 'locId$',
    //     width: 140,
    //     ellipsis: true,
    //     ...getColumnSearchProps('locId$'),
    // },
    // {
    //     title: formatMessage('db.man_loc_detl.mat_id', '商品'),
    //     dataIndex: 'matId$',
    //     width: 140,
    //     ellipsis: true,
    //     ...getColumnSearchProps('matId$'),
    // },
    {
        title: formatMessage('db.man_loc_detl.order_no', '订单号'),
        dataIndex: 'orderNo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('orderNo'),
    },
    {
        title: formatMessage('db.man_loc_detl.anfme', '数量'),
        dataIndex: 'anfme',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('anfme'),
    },
    {
        title: formatMessage('db.man_loc_detl.freeze', '是否冻结'),
        dataIndex: 'freeze$',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('freeze$'),
    },
    // {
    //     title: formatMessage('db.man_loc_detl.status', '状态'),
    //     dataIndex: 'status$',
    //     width: 140,
    //     ellipsis: true,
    //     ...getColumnSearchProps('status$'),
    // },
    // {
    //   title: formatMessage('db.man_loc_detl.create_time', '添加时间'),
    //   dataIndex: 'createTime$',
    //   width: 140,
    //   ellipsis: true,
    //   ...getColumnSearchProps('createTime$'),
    // },
    // {
    //   title: formatMessage('db.man_loc_detl.create_by', '添加人员'),
    //   dataIndex: 'createBy$',
    //   width: 140,
    //   ellipsis: true,
    //   ...getColumnSearchProps('createBy$'),
    // },
    // {
    //     title: formatMessage('db.man_loc_detl.update_time', '修改时间'),
    //     dataIndex: 'updateTime$',
    //     width: 140,
    //     ellipsis: true,
    //     ...getColumnSearchProps('updateTime$'),
    // },
    // {
    //     title: formatMessage('db.man_loc_detl.update_by', '修改人员'),
    //     dataIndex: 'updateBy$',
    //     width: 140,
    //     ellipsis: true,
    //     ...getColumnSearchProps('updateBy$'),
    // },
    {
        title: formatMessage('db.man_loc_detl.memo', '备注'),
        dataIndex: 'memo',
        width: 140,
        ellipsis: true,
        ...getColumnSearchProps('memo'),
    },
]

let fieldList = [];
//加载扩展字段
async function getColumns() {
    let fieldResp = await post('/api/matField/list', {
        unique: 1
    })
    let fieldResult = fieldResp.data;
    let tmp = state.columns;
    if (fieldResult.code == 200) {
        let data = fieldResult.data;
        data.forEach((item) => {
            let filed = {
                title: formatMessage(item.language, item.describe),
                name: item.name,
                dataIndex: item.name,
                key: item.name,
                width: 140,
                editable: true,
                ...getColumnSearchProps(item.name),
            }
            tmp.push(filed)
            fieldList.push(filed)
        })

        tmp = tmp.concat(columnsOther)

        state.columns = tmp;
    } else if (result.code === 401) {
        message.error(result.msg);
        logout()
    } else {
        message.error(result.msg);
    }
}

const handleMatQueryOk = (result) => {
    let tmp = [];

    if (tableData.value != undefined) {
        tmp = [...tableData.value]
    }

    for (let i = 0; i < result.length; i++) {
        let item = result[i]
        item.anfme = 0;
        item.qty = 0;
        item.matId = item.id;
        item.id = null;

        fieldList.forEach((filed) => {
            item[filed.key] = ''
        })

        tmp.push(item)
    }

    tableData.value = tmp;
}

const onSourceLocNoChange = () => {
    state.loading = true;
    tableData.value = null;

    postForm('/api/loc/search/like/locNo', {
        locNo: sourceLocNo.value,
        test: "123",
        quer: ""
    }).then(resp => {
        let result = resp.data;
        if (result.code == 200) {
            let detls = [];
            result.data.forEach((item) => {
                item.qty = item.anfme;
                detls.push(item)
            })
            tableData.value = detls;
            state.loading = false;
        } else {
            message.error(result.msg);
            tableData.value = null;
        }
    })
}

const submitTransfer = () => {
    Modal.confirm({
        title: formatMessage('page.stockTransfer.transfer', '库存移转'),
        content: formatMessage('page.stockTransfer.confirm', '确定库存移转吗？'),
        maskClosable: true,
        onOk: async () => {
            confirmTransfer()
        },
    });

}

const confirmTransfer = () => {
    if (sourceLocNo.value == null) {
        message.error(formatMessage('page.stockTransfer.sourceLocNoNull', '请输入源库位'));
        return;
    }

    if(targetLocNo.value == null) {
        message.error(formatMessage('page.stockTransfer.targetLocNoNull', '目标库位为空'));
        return;
    }

    post('/api/loc/transfer', {
        sourceLocNo: sourceLocNo.value,
        targetLocNo: targetLocNo.value
    }).then(resp => {
        let result = resp.data;
        if (result.code == 200) {
            message.success(formatMessage('page.stockTransfer.success', '库存移转成功'));

            sourceLocNo.value = null;
            targetLocNo.value = null;
        } else {
            message.error(result.msg);
        }
    })
}

const locNoQueryList = ref(null);
locNoQuery("");
function locNoQuery(locNo) {
    postForm('/api/loc/search/empty/locNo', {
        locNo: locNo
    }).then(resp => {
        let result = resp.data;
        let tmp = []
        result.data.forEach((item) => {
            tmp.push({
                value: item.locNo,
                label: item.locNo
            })
        })
        locNoQueryList.value = tmp;
    })
}

const locNoSearch = (val) => {
    locNoQuery(val)
}

</script>

<script>
export default {
    name: '库存移转'
}
</script>

<template>
    <div>
        <div style="margin-bottom: 20px;display: flex;align-items: center;">
            <a-input v-model:value="sourceLocNo" :placeholder="formatMessage('page.stockTransfer.sourceLocNo', '源库位')"
                style="width: 200px;" @change="onSourceLocNoChange" />
            <span style="margin-left: 10px;margin-right: 10px;">-</span>
            <a-select v-model:value="targetLocNo" :placeholder="formatMessage('page.stockTransfer.targetLocNo', '目标库位')"
                style="width: 200px" show-search :options="locNoQueryList" @search="locNoSearch" optionFilterProp="label"
                optionLabelProp="label">
            </a-select>
        </div>
        <div class="table-header">
            <div>
                <a-button type="primary" @click="submitTransfer">库位移转</a-button>
            </div>
        </div>
        <a-table :row-selection="{ selectedRowKeys: state.selectedRowKeys, onChange: onSelectChange }"
            :data-source="tableData" :defaultExpandAllRows="false" :key="TABLE_KEY" rowKey="id"
            :scroll="{ y: 768, scrollToFirstRowOnChange: true }" :columns="state.columns" :loading="state.loading"
            @resizeColumn="handleResizeColumn">
            <template #bodyCell="{ column, text, record }">

            </template>
        </a-table>

        <MatQueryView ref="matQueryChild" @handle-ok="handleMatQueryOk" />
    </div>
</template>

<style></style>
